==> cdi-tck-impl-1.2.5.Final-sources.jar: org/jboss/cdi/tck/tests/context/dependent/ejb/DependentContextEjbTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.context.dependent.ejb;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.cdi.Sections.DEPENDENT_DESTRUCTION;

import javax.enterprise.context.spi.CreationalContext;
import javax.enterprise.inject.spi.Bean;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

@SpecVersion(spec = "cdi", version = "1.1 Final Release")
public class DependentContextEjbTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(DependentContextEjbTest.class).build();
    }

    @Test(groups =  INTEGRATION)
    @SpecAssertion(section = DEPENDENT_DESTRUCTION, id = "aaab")
    public void testDestroyingEjbDestroysDependents() throws Exception {
        assert getBeans(HouseLocal.class).size() == 1;
        Bean<HouseLocal> bean = getBeans(HouseLocal.class).iterator().next();
        CreationalContext<HouseLocal> creationalContext = getCurrentManager().createCreationalContext(bean);
        HouseLocal instance = bean.create(creationalContext);
        instance.open().getTable().lay();
        Room.destroyed = false;
        Table.destroyed = false;
        House.destroyed = false;
        bean.destroy(instance, creationalContext);
        assert House.destroyed;
        assert Room.destroyed;
        assert Table.destroyed;
    }

    @Test(groups =  INTEGRATION)
    @SpecAssertion(section = DEPENDENT_DESTRUCTION, id = "aaab")
    public void testDestroyingEjbDestroysDependentSimples() throws Exception {
        assert getBeans(FarmLocal.class).size() == 1;
        Bean<FarmLocal> farmBean = getBeans(FarmLocal.class).iterator().next();
        CreationalContext<FarmLocal> creationalContext = getCurrentManager().createCreationalContext(farmBean);
        FarmLocal farm = farmBean.create(creationalContext);
        Horse.destroyed = false;
        Stable.destroyed = false;
        Farm.destroyed = false;
        farmBean.destroy(farm, creationalContext);
        assert Farm.destroyed;
        assert Horse.destroyed;
        assert Stable.destroyed;
    }

}

==> cdi-tck-impl-2.0.0.Final-sources.jar: org/jboss/cdi/tck/tests/context/dependent/ejb/DependentContextEjbTest.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc., and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,  
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.cdi.tck.tests.context.dependent.ejb;

import static org.jboss.cdi.tck.TestGroups.INTEGRATION;
import static org.jboss.cdi.tck.cdi.Sections.DEPENDENT_DESTRUCTION_EE;

import javax.enterprise.context.spi.CreationalContext;
import javax.enterprise.inject.spi.Bean;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.cdi.tck.AbstractTest;
import org.jboss.cdi.tck.shrinkwrap.WebArchiveBuilder;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.jboss.test.audit.annotations.SpecAssertion;
import org.jboss.test.audit.annotations.SpecVersion;
import org.testng.annotations.Test;

@SpecVersion(spec = "cdi", version = "2.0-PFD")
public class DependentContextEjbTest extends AbstractTest {

    @Deployment
    public static WebArchive createTestArchive() {
        return new WebArchiveBuilder().withTestClassPackage(DependentContextEjbTest.class).build();
    }

    @Test(groups =  INTEGRATION)
    @SpecAssertion(section = DEPENDENT_DESTRUCTION_EE, id = "aaab")
    public void testDestroyingEjbDestroysDependents() throws Exception {
        assert getBeans(HouseLocal.class).size() == 1;
        Bean<HouseLocal> bean = getBeans(HouseLocal.class).iterator().next();
        CreationalContext<HouseLocal> creationalContext = getCurrentManager().createCreationalContext(bean);
        HouseLocal instance = bean.create(creationalContext);
        instance.open().getTable().lay();
        Room.destroyed = false;
        Table.destroyed = false;
        House.destroyed = false;
        bean.destroy(instance, creationalContext);
        assert House.destroyed;
        assert Room.destroyed;
        assert Table.destroyed;
    }

    @Test(groups =  INTEGRATION)
    @SpecAssertion(section = DEPENDENT_DESTRUCTION_EE, id = "aaab")
    public void testDestroyingEjbDestroysDependentSimples() throws Exception {
        assert getBeans(FarmLocal.class).size() == 1;
        Bean<FarmLocal> farmBean = getBeans(FarmLocal.class).iterator().next();
        CreationalContext<FarmLocal> creationalContext = getCurrentManager().createCreationalContext(farmBean);
        FarmLocal farm = farmBean.create(creationalContext);
        Horse.destroyed = false;
        Stable.destroyed = false;
        Farm.destroyed = false;
        farmBean.destroy(farm, creationalContext);
        assert Farm.destroyed;
        assert Horse.destroyed;
        assert Stable.destroyed;
    }

}
